==> ace-api-0.5.12.tgz: package/lib/roles.js <==
const _ = require('lodash');

const roles = [
  {
    name: 'Admin',
    slug: 'admin',
    permissions: {
      entityGrid: true,

      entityCreate: true,
      entityRead: true,
      entityUpdate: true,
      entityDelete: true,

      taxonomyCreate: true,
      taxonomyRead: true,
      taxonomyUpdate: true,
      taxonomyDelete: true,

      fileCreate: true,
      fileRead: true,
      fileUpdate: true,
      fileDelete: true,

      config: false,
      schema: false,
      user: true,
      settings: true,
      tools: true,
      ecommerce: true,
    },
  },
  {
    name: 'Editor',
    slug: 'editor',
    permissions: {
      entityGrid: true,

      entityCreate: true,
      entityRead: true,
      entityUpdate: true,
      entityDelete: true,

      taxonomyCreate: true,
      taxonomyRead: true,
      taxonomyUpdate: true,
      taxonomyDelete: true,

      fileCreate: true,
      fileRead: true,
      fileUpdate: true,
      fileDelete: true,

      config: false,
      schema: false,
      user: false,
      settings: false,
      tools: false,
      ecommerce: false,
    },
  },
  {
    name: 'Guest',
    slug: 'guest',
    permissions: {
      entityGrid: true,

      entityCreate: false,
      entityRead: true,
      entityUpdate: false,
      entityDelete: false,

      taxonomyCreate: false,
      taxonomyRead: true,
      taxonomyUpdate: false,
      taxonomyDelete: false,

      fileCreate: false,
      fileRead: true,
      fileUpdate: false,
      fileDelete: false,

      config: false,
      schema: false,
      user: false,
      settings: false,
      tools: false,
      ecommerce: false,
    },
  },
];

class Roles {
  static roles() {
    return roles.map(role => Object.freeze(role));
  }
  static role(slug) {
    return _.find(Roles.roles(), { slug });
  }
}

module.exports = Roles;

==> ace-api-0.7.50.tgz: package/lib/roles.js <==
const _ = require('lodash');

const roles = [
  {
    name: 'Admin',
    slug: 'admin',
    permissions: {
      entityGrid: true,

      entityCreate: true,
      entityRead: true,
      entityUpdate: true,
      entityDelete: true,

      taxonomyCreate: true,
      taxonomyRead: true,
      taxonomyUpdate: true,
      taxonomyDelete: true,

      fileCreate: true,
      fileRead: true,
      fileUpdate: true,
      fileDelete: true,

      config: false,
      schema: false,
      user: true,
      settings: true,
      userSettings: true,
      tools: true,
      ecommerce: true,
    },
  },
  {
    name: 'Editor',
    slug: 'editor',
    permissions: {
      entityGrid: true,

      entityCreate: true,
      entityRead: true,
      entityUpdate: true,
      entityDelete: true,

      taxonomyCreate: true,
      taxonomyRead: true,
      taxonomyUpdate: true,
      taxonomyDelete: true,

      fileCreate: true,
      fileRead: true,
      fileUpdate: true,
      fileDelete: true,

      config: false,
      schema: false,
      user: false,
      settings: false,
      userSettings: true,
      tools: false,
      ecommerce: false,
    },
  },
  {
    name: 'Guest',
    slug: 'guest',
    permissions: {
      entityGrid: true,

      entityCreate: false,
      entityRead: true,
      entityUpdate: false,
      entityDelete: false,

      taxonomyCreate: false,
      taxonomyRead: true,
      taxonomyUpdate: false,
      taxonomyDelete: false,

      fileCreate: false,
      fileRead: true,
      fileUpdate: false,
      fileDelete: false,

      config: false,
      schema: false,
      user: false,
      settings: false,
      userSettings: false,
      tools: false,
      ecommerce: false,
    },
  },
];

class Roles {
  roles() {
    return roles.map(role => Object.freeze(role));
  }
  role(slug) {
    return _.find(this.roles(), { slug });
  }
}

module.exports = Roles;
